
#ifndef ___biji_marshal_MARSHAL_H__
#define ___biji_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:ENUM,ENUM,POINTER (./biji-marshalers.list:1) */
extern void _biji_marshal_VOID__ENUM_ENUM_POINTER (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

/* VOID:BOOLEAN,BOOLEAN (./biji-marshalers.list:2) */
extern void _biji_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:POINTER,ENUM (./biji-marshalers.list:3) */
extern void _biji_marshal_VOID__POINTER_ENUM (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

G_END_DECLS

#endif /* ___biji_marshal_MARSHAL_H__ */

